@@ -8,3 +8,5 @@ from .fast_opt_svr_hyperparams import fast_opt_svr_hyperparams
 from .fast_opt_svr_hyperparams import maximize_variance_of_gram_matrix
 from .iot import iot_obj_func
 from .iot import iot
+from .opt_dnn_hyperparams import bo_dnn_hyperparams
+from .opt_dnn_hyperparams import gs_dnn_hyperparams
