@@ -6,10 +6,13 @@
 
 from .metrics import k3nerror
 from .metrics import r2lm
+from .validation import DCEGridSearchCV
 from .validation import midknn
 from .validation import make_midknn_dataset
 from .validation import y_randomization
 from .validation import y_randomization_with_hyperparam_opt
 from .validation import double_cross_validation
+from .validation import double_cross_validation_group
 from .validation import mae_cce
+from .validation import train_test_split_group
 from .applicability_domain import ApplicabilityDomain
